@@ -45,7 +45,7 @@ class MainCli:
             if file.endswith(".zip"):
                 os.remove(file)
         data_dir = (data_path+'/devices_data.xlsx')
-        command_dir = (data_path+'/show_command.txt')
+        command_dir = (data_path+'/show_command.xlsx')
         call_function_capture=function_capture(data_dir,command_dir,capture_path)
         chg_dir = os.chdir(capture_path)
         current_dir=os.getcwd()
@@ -66,12 +66,10 @@ class MainCli:
         to_docx=to_docx()
         to_docx.to_docx()
         time.sleep(3)
-        for file in files:
-            if file.endswith("db"):
-                os.remove(file)
         src_mv = (capture_path+'preventive_maintenance.docx')
         dst_mv = (result_path+'preventive_maintenance.docx')
         shutil.move(src_mv,dst_mv)
+        os.remove("pmdb")
 
     def showEnvironment():
         chg_dir = os.chdir(capture_path)
@@ -84,12 +82,10 @@ class MainCli:
         env_docx=env_docx()
         env_docx.env_docx()
         time.sleep(3)
-        for file in files:
-            if file.endswith("db"):
-                os.remove(file)
         src_mv = (capture_path+'show_environment.docx')
         dst_mv = (result_path+'show_environment.docx')
         shutil.move(src_mv,dst_mv)
+        os.remove("env_pmdb")
 
     def showLog():
         chg_dir = os.chdir(capture_path)
@@ -269,6 +265,25 @@ class MainCli:
         dst_mv = (result_path+'show_log.docx')
         shutil.move(src_mv,dst_mv)
 
+    def showLogWeb(month_list):
+        chg_dir = os.chdir(capture_path)
+        current_dir=os.getcwd()
+        from netoprmgr.script.get_log import get_log
+
+        month_list = month_list
+
+        files = os.listdir(current_dir)
+        get_log=get_log(files,month_list)
+        get_log.get_log()
+        
+        time.sleep(3)
+        for file in files:
+            if file.endswith("db"):
+                os.remove(file)
+        src_mv = (capture_path+'show_log.docx')
+        dst_mv = (result_path+'show_log.docx')
+        shutil.move(src_mv,dst_mv)
+
     def createNewReport():
         chg_dir = os.chdir(capture_path)
         current_dir=os.getcwd()
@@ -280,12 +295,10 @@ class MainCli:
         convert_docx=convert_docx()
         convert_docx.convert_docx()
         time.sleep(3)
-        for file in files:
-            if file.endswith("db"):
-                os.remove(file)
         src_mv = (capture_path+'preventive_maintenance.docx')
         dst_mv = (result_path+'preventive_maintenance.docx')
         shutil.move(src_mv,dst_mv)
+        os.remove("pmdb")
 
     def createTemplate():
         chg_dir = os.chdir(data_path)
@@ -314,4 +327,34 @@ class MainCli:
             except:
                 pass
             count_row+=1
-        
\ No newline at end of file
+        
+if __name__ == "__main__":
+    answer=input(
+    'Type "template" to create template on data folder\n\n'
+    'Press Number for MENU :\n'
+    'Type "web" for accessing web version\n'
+    '0. Device Identification (Still Development)\n'
+    '1. Device Availability Check\n'
+    '2. Capture\n'
+    '3. Create Report\n'
+    '4. Show Environment Report\n'
+    '5. Show Log Report\n'
+    '6. New Create Report\n'
+    'Type "quit" to quit program\n'
+    )
+    if answer == '0':
+        MainCli.deviceIdentification()
+    elif answer == '1':
+        MainCli.deviceAvailability()
+    elif answer == '2':
+        MainCli.captureDevice()
+    elif answer == '3':
+        MainCli.createReport()
+    elif answer == '4':
+        MainCli.showEnvironment()
+    elif answer == '5':
+        MainCli.showLog()
+    elif answer == '6':
+        MainCli.createNewReport()
+    elif answer == 'web':
+        MainCli.webAccess()
\ No newline at end of file
